pub struct CreateNamespaceRequest {
pub namespace: Vec<String>,
pub properties: Option<HashMap<String, String>>,
}Fields
namespace: Vec<String>Reference to one or more levels of a namespace
properties: Option<HashMap<String, String>>Configured string to string map of properties for the namespace
Implementations
Sourceimpl CreateNamespaceRequest
impl CreateNamespaceRequest
pub fn new(namespace: Vec<String>) -> CreateNamespaceRequest